@@ -10,11 +10,14 @@
 #ifdef HAS_DBUS
 #include <KLocalizedString>
 #include <QDBusConnection>
-#include <QDBusMessage>
 #include <QDBusReply>
 #include <QGuiApplication>
 #endif
 
+#ifdef Q_OS_ANDROID
+#include <QJniObject>
+#endif
+
 VideoController::VideoController(QObject *parent)
     : QObject(parent)
     , m_videoModel(new VideoModel(this))
@@ -83,6 +86,24 @@ VideoController::VideoController(QObject *parent)
             }
         }
 #endif
+
+#ifdef Q_OS_ANDROID
+        QNativeInterface::QAndroidApplication::runOnAndroidMainThread([shouldInhibit] {
+            QJniObject activity = QNativeInterface::QAndroidApplication::context();
+            if (activity.isValid()) {
+                QJniObject window = activity.callObjectMethod("getWindow", "()Landroid/view/Window;");
+
+                if (window.isValid()) {
+                    const int FLAG_KEEP_SCREEN_ON = 128;
+                    if (shouldInhibit) {
+                        window.callMethod<void>("addFlags", "(I)V", FLAG_KEEP_SCREEN_ON);
+                    } else {
+                        window.callMethod<void>("clearFlags", "(I)V", FLAG_KEEP_SCREEN_ON);
+                    }
+                }
+            }
+        });
+#endif
     });
     connect(this, &VideoController::positionChanged, this, [this] {
         auto currentPosition = position();
@@ -207,7 +228,7 @@ void VideoController::setCurrentPlayer(MpvObject *mpvObject)
         m_currentPlayer->setProperty(QStringLiteral("stream-lavf-o"), QStringLiteral(""));
     }
 
-    PlasmaTubeSettings settings(KSharedConfig::openConfig(QStringLiteral("plasmatuberc"), KConfig::SimpleConfig, QStandardPaths::AppConfigLocation));
+    Settings settings(KSharedConfig::openConfig(QStringLiteral("plasmatuberc"), KConfig::SimpleConfig, QStandardPaths::AppConfigLocation));
     if (settings.proxyType() == 1) {
         QString proxyString = QStringLiteral("http://%1:%2@%3:%4")
                                   .arg(settings.proxyUser(), settings.proxyPassword(), settings.proxyHost(), QString::number(settings.proxyPort()));
